==> ldap-account-manager_7.7.orig.tar.bz2: ldap-account-manager-7.7/templates/lib/extra/ckeditor/plugins/link/lang/hu.js <==
﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'hu', {
	acccessKey: 'Billentyűkombináció',
	advanced: 'További opciók',
	advisoryContentType: 'Súgó tartalomtípusa',
	advisoryTitle: 'Súgócimke',
	anchor: {
		toolbar: 'Horgony beillesztése/szerkesztése',
		menu: 'Horgony tulajdonságai',
		title: 'Horgony tulajdonságai',
		name: 'Horgony neve',
		errorName: 'Kérem adja meg a horgony nevét',
		remove: 'Horgony eltávolítása'
	},
	anchorId: 'Azonosító szerint',
	anchorName: 'Horgony név szerint',
	charset: 'Hivatkozott tartalom kódlapja',
	cssClasses: 'Stíluskészlet',
	download: 'Kötelező letöltés',
	displayText: 'Megjelenített szöveg',
	emailAddress: 'E-Mail cím',
	emailBody: 'Üzenet',
	emailSubject: 'Üzenet tárgya',
	id: 'Id',
	info: 'Alaptulajdonságok',
	langCode: 'Írás iránya',
	langDir: 'Írás iránya',
	langDirLTR: 'Balról jobbra',
	langDirRTL: 'Jobbról balra',
	menu: 'Hivatkozás módosítása',
	name: 'Név',
	noAnchors: '(Nincs horgony a dokumentumban)',
	noEmail: 'Adja meg az E-Mail címet',
	noUrl: 'Adja meg a hivatkozás webcímét',
	noTel: 'Adja meg a telefonszámot',
	other: '<más>',
	phoneNumber: 'Telefonszám',
	popupDependent: 'Szülőhöz kapcsolt (csak Netscape)',
	popupFeatures: 'Felugró ablak jellemzői',
	popupFullScreen: 'Teljes képernyő (csak IE)',
	popupLeft: 'Bal pozíció',
	popupLocationBar: 'Címsor',
	popupMenuBar: 'Menü sor',
	popupResizable: 'Átméretezés',
	popupScrollBars: 'Gördítősáv',
	popupStatusBar: 'Állapotsor',
	popupToolbar: 'Eszköztár',
	popupTop: 'Felső pozíció',
	rel: 'Kapcsolat típusa',
	selectAnchor: 'Horgony választása',
	styles: 'Stílus',
	tabIndex: 'Tabulátor index',
	target: 'Tartalom megjelenítése',
	targetFrame: '<keretben>',
	targetFrameName: 'Keret neve',
	targetPopup: '<felugró ablakban>',
	targetPopupName: 'Felugró ablak neve',
	title: 'Hivatkozás tulajdonságai',
	toAnchor: 'Horgony az oldalon',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toPhone: 'Telefon',
	toolbar: 'Hivatkozás beillesztése/módosítása',
	type: 'Hivatkozás típusa',
	unlink: 'Hivatkozás törlése',
	upload: 'Feltöltés'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/link/lang/hu.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'link', 'hu', {
	acccessKey: 'Billentyűkombináció',
	advanced: 'További opciók',
	advisoryContentType: 'Súgó tartalomtípusa',
	advisoryTitle: 'Súgócimke',
	anchor: {
		toolbar: 'Horgony beillesztése/szerkesztése',
		menu: 'Horgony tulajdonságai',
		title: 'Horgony tulajdonságai',
		name: 'Horgony neve',
		errorName: 'Kérem adja meg a horgony nevét',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'Horgony eltávolítása'
	},
	anchorId: 'Azonosító szerint',
	anchorName: 'Horgony név szerint',
	charset: 'Hivatkozott tartalom kódlapja',
	cssClasses: 'Stíluskészlet',
	download: 'Kötelező letöltés',
	displayText: 'Megjelenített szöveg',
	emailAddress: 'E-Mail cím',
	emailBody: 'Üzenet',
	emailSubject: 'Üzenet tárgya',
	id: 'Id',
	info: 'Alaptulajdonságok',
	langCode: 'Írás iránya',
	langDir: 'Írás iránya',
	langDirLTR: 'Balról jobbra',
	langDirRTL: 'Jobbról balra',
	menu: 'Hivatkozás módosítása',
	name: 'Név',
	noAnchors: '(Nincs horgony a dokumentumban)',
	noEmail: 'Adja meg az E-Mail címet',
	noUrl: 'Adja meg a hivatkozás webcímét',
	noTel: 'Adja meg a telefonszámot',
	other: '<más>',
	phoneNumber: 'Telefonszám',
	popupDependent: 'Szülőhöz kapcsolt (csak Netscape)',
	popupFeatures: 'Felugró ablak jellemzői',
	popupFullScreen: 'Teljes képernyő (csak IE)',
	popupLeft: 'Bal pozíció',
	popupLocationBar: 'Címsor',
	popupMenuBar: 'Menü sor',
	popupResizable: 'Átméretezés',
	popupScrollBars: 'Gördítősáv',
	popupStatusBar: 'Állapotsor',
	popupToolbar: 'Eszköztár',
	popupTop: 'Felső pozíció',
	rel: 'Kapcsolat típusa',
	selectAnchor: 'Horgony választása',
	styles: 'Stílus',
	tabIndex: 'Tabulátor index',
	target: 'Tartalom megjelenítése',
	targetFrame: '<keretben>',
	targetFrameName: 'Keret neve',
	targetPopup: '<felugró ablakban>',
	targetPopupName: 'Felugró ablak neve',
	title: 'Hivatkozás tulajdonságai',
	toAnchor: 'Horgony az oldalon',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toPhone: 'Telefon',
	toolbar: 'Hivatkozás beillesztése/módosítása',
	type: 'Hivatkozás típusa',
	unlink: 'Hivatkozás törlése',
	upload: 'Feltöltés'
} );
